@@ -97,10 +97,10 @@ def process_template(template,
 
     resource_collection_dict = {}
     max_stack_resources = 0
-    ou_fetcher = lambda ou, recursive: [a["Id"] for a in lookup.lookup_accounts_for_ou(session, ou,
+    ou_fetcher = lambda ou, recursive: lookup.lookup_accounts_for_ou(session, ou,
             recursive=recursive,
             cache=ou_accounts_cache,
-            exclude_org_mgmt_acct=True)]
+            exclude_org_mgmt_acct=True)
 
     for resource_name, config in configs.items():
         resource_collection = resources.get_resources_from_config(
